Description Usage Arguments Details Author(s)
From NamedList to Datasets
1 | getDatasets(types, inputData, labels, colors, detailedOptions)
|
types |
list of type of charts |
inputData |
DataFrame with columns "x","y","r" |
labels |
Names of columns which be used to build charts |
colors |
list of background colors which be used |
detailedOptions |
list of detailed options like "fill" option for line charts |
Prepares datasets in the form of a list to be converted to JSON
Jacek Myna, Aleksandra Łuczak, Agata Pałdyna, Tomasz Radzikowski, Jan Sawicki
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.