Description Usage Arguments Details Author(s)
Main function
1 2 3 |
types |
list of types of charts |
inputData |
data.frame with columns "x","y","r" |
xData |
data which be used to plot x axis (column of inputData) |
yData |
data which be used to plot y axis (column of inputData) |
labels |
list name of labels |
rData |
data which be used to plot r axis, e.g. for bubble charts (column of inputData) |
colors |
list of background colors which be used |
options |
list of options to create JSON |
detailedOptions |
list of lists of additional options; only "fill" for line graphs is handled |
base64 |
boolean describing if the url should or should not be encoded in base64 |
Creates a link to quickchart with chart/charts based on inputData.
Jacek Myna, Aleksandra Łuczak, Agata Pałdyna, Tomasz Radzikowski, Jan Sawicki
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.